==> haskell-feed-1.2.0.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-feed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: feed
version: 1.2.0.1
id: feed-1.2.0.1-1yPS8FSthUi8M2iihI0aY3
key: feed-1.2.0.1-1yPS8FSthUi8M2iihI0aY3
license: BSD-3-Clause
maintainer: Adam Bergmark <adam@bergmark.nl>
author: Sigbjorn Finne <sof@forkIO.com>
homepage: https://github.com/bergmark/feed
synopsis: Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
description:
    Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
    .
    To help working with the multiple feed formats we'\''ve
    ended up with, this set of modules provides parsers,
    pretty printers and some utility code for querying
    and just generally working with a concrete representation
    of feeds in Haskell.
    .
    See here for an example of how to create an Atom feed:
    <https://github.com/bergmark/feed/blob/master/tests/Example/CreateAtom.hs>
    .
    For basic reading and editing of feeds, consult
    the documentation of the Text.Feed.* hierarchy.
category: Text
abi: ffda17b55a7f3355beda4675d06ff8df
exposed: True
exposed-modules:
    Text.Atom.Feed Text.Atom.Feed.Export Text.Atom.Feed.Import
    Text.Atom.Feed.Link Text.Atom.Feed.Validate Text.Atom.Pub
    Text.Atom.Pub.Export Text.DublinCore.Types Text.Feed.Constructor
    Text.Feed.Export Text.Feed.Import Text.Feed.Query
    Text.Feed.Translate Text.Feed.Types Text.Feed.Util Text.RSS.Export
    Text.RSS.Import Text.RSS.Syntax Text.RSS1.Export Text.RSS1.Import
    Text.RSS1.Syntax Text.RSS1.Utils
hidden-modules: Data.Text.Util Data.XML.Compat
import-dirs: /usr/lib/ghc-8.6.5/site-local/feed-1.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/feed-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-feed
hs-libraries: HSfeed-1.2.0.1-1yPS8FSthUi8M2iihI0aY3
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bytestring-0.10.8.2 old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    xml-conduit-1.8.0.1-ItKMKBLRSqtFuvW7keDBPV
    xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
haddock-interfaces: /usr/share/doc/haskell-feed/html/feed.haddock
haddock-html: /usr/share/doc/haskell-feed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-feed-1.2.0.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-feed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: feed
version: 1.2.0.1
id: feed-1.2.0.1-3ckctZ1Bil644mncajByT
key: feed-1.2.0.1-3ckctZ1Bil644mncajByT
license: BSD-3-Clause
maintainer: Adam Bergmark <adam@bergmark.nl>
author: Sigbjorn Finne <sof@forkIO.com>
homepage: https://github.com/bergmark/feed
synopsis: Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
description:
    Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
    .
    To help working with the multiple feed formats we'\''ve
    ended up with, this set of modules provides parsers,
    pretty printers and some utility code for querying
    and just generally working with a concrete representation
    of feeds in Haskell.
    .
    See here for an example of how to create an Atom feed:
    <https://github.com/bergmark/feed/blob/master/tests/Example/CreateAtom.hs>
    .
    For basic reading and editing of feeds, consult
    the documentation of the Text.Feed.* hierarchy.
category: Text
abi: 8ad7ec92a7b99964354a9e3a51229931
exposed: True
exposed-modules:
    Text.Atom.Feed Text.Atom.Feed.Export Text.Atom.Feed.Import
    Text.Atom.Feed.Link Text.Atom.Feed.Validate Text.Atom.Pub
    Text.Atom.Pub.Export Text.DublinCore.Types Text.Feed.Constructor
    Text.Feed.Export Text.Feed.Import Text.Feed.Query
    Text.Feed.Translate Text.Feed.Types Text.Feed.Util Text.RSS.Export
    Text.RSS.Import Text.RSS.Syntax Text.RSS1.Export Text.RSS1.Import
    Text.RSS1.Syntax Text.RSS1.Utils
hidden-modules: Data.Text.Util Data.XML.Compat
import-dirs: /usr/lib/ghc-8.6.5/site-local/feed-1.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/feed-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-feed
hs-libraries: HSfeed-1.2.0.1-3ckctZ1Bil644mncajByT
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bytestring-0.10.8.2 old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    xml-conduit-1.8.0.1-5cZFy2zECMFJ5YEWhdhPDt
    xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
haddock-interfaces: /usr/share/doc/haskell-feed/html/feed.haddock
haddock-html: /usr/share/doc/haskell-feed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
